svn commit: r302665 - stable/11/sys/net

Bryan Drewery bdrewery at FreeBSD.org
Tue Jul 12 17:22:14 UTC 2016


Author: bdrewery
Date: Tue Jul 12 17:22:13 2016
New Revision: 302665
URL: https://svnweb.freebsd.org/changeset/base/302665

Log:
  MFC r302439:
  
    iflib: Fix typo in 'iflib_rx_miss_bufs' sysctl name
  
  Approved by:	re (gjb)

Modified:
  stable/11/sys/net/iflib.c
Directory Properties:
  stable/11/   (props changed)

Modified: stable/11/sys/net/iflib.c
==============================================================================
--- stable/11/sys/net/iflib.c	Tue Jul 12 15:46:53 2016	(r302664)
+++ stable/11/sys/net/iflib.c	Tue Jul 12 17:22:13 2016	(r302665)
@@ -626,12 +626,12 @@ MODULE_DEPEND(iflib, netmap, 1, 1, 1);
 /*
  * device-specific sysctl variables:
  *
  * ixl_crcstrip: 0: keep CRC in rx frames (default), 1: strip it.
  *	During regular operations the CRC is stripped, but on some
  *	hardware reception of frames not multiple of 64 is slower,
  *	so using crcstrip=0 helps in benchmarks.
  *
- * ixl_rx_miss, ixl_rx_miss_bufs:
+ * iflib_rx_miss, iflib_rx_miss_bufs:
  *	count packets that might be missed due to lost interrupts.
  */
 SYSCTL_DECL(_dev_netmap);
@@ -646,7 +646,7 @@ SYSCTL_INT(_dev_netmap, OID_AUTO, iflib_
 int iflib_rx_miss, iflib_rx_miss_bufs;
 SYSCTL_INT(_dev_netmap, OID_AUTO, iflib_rx_miss,
     CTLFLAG_RW, &iflib_rx_miss, 0, "potentially missed rx intr");
-SYSCTL_INT(_dev_netmap, OID_AUTO, ixl_rx_miss_bufs,
+SYSCTL_INT(_dev_netmap, OID_AUTO, iflib_rx_miss_bufs,
     CTLFLAG_RW, &iflib_rx_miss_bufs, 0, "potentially missed rx intr bufs");
 
 /*
@@ -626,12 +626,12 @@ MODULE_DEPEND(iflib, netmap, 1, 1, 1);
  * device-specific sysctl variables:
  *
- * ixl_crcstrip: 0: keep CRC in rx frames (default), 1: strip it.
+ * iflib_crcstrip: 0: keep CRC in rx frames (default), 1: strip it.
  *	During regular operations the CRC is stripped, but on some
  *	hardware reception of frames not multiple of 64 is slower,


More information about the svn-src-all mailing list